RxnBool class

A reactive wrapper for nullable bool values.

Inheritance
Available extensions

Constructors

RxnBool([bool? initial])
Creates a RxnBool with an optional initial value.

Properties

firstRebuild bool
Whether this is the first rebuild cycle for this Rx value.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
isDisposed bool
Whether this notifier has been disposed.
no setterinherited
isFalse bool

Available on Rx<bool>, provided by the RxBoolExt extension

Returns true if the current value is false.
no setter
isFalse bool?

Available on Rx<bool?>, provided by the RxnBoolExt extension

Returns the inverse of the current value, or null if value is null.
no setter
isTrue bool

Available on Rx<bool>, provided by the RxBoolExt extension

Returns true if the current value is true.
no setter
isTrue bool?

Available on Rx<bool?>, provided by the RxnBoolExt extension

Returns the current nullable value.
no setter
listenersLength int
The current number of registered listeners.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sentToStream bool
Whether the current value has been sent to the internal stream.
getter/setter pairinherited
stream Stream<bool?>
no setterinherited
string String
Same as toString() but using a getter.
no setterinherited
subject StreamController<bool?>
no setterinherited
value bool?
The current value of the object.
getter/setter pairinherited

Methods

addError(Object error, [StackTrace? stackTrace]) → void
inherited
addListener(GetStateUpdate listener) → Disposer
Registers a listener and returns a Disposer to unregister it.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
Adds a listener to the group identified by key.
inherited
bindStream(Stream<bool?> stream) → void
Binds an existing Stream<T> to this Rx<T> to keep the values in sync. You can bind multiple sources to update the value. Closing the subscription will happen automatically when the observer Widget (GetX or Obx) gets unmounted from the Widget tree.
inherited
call([bool? v]) bool?
Makes a direct update of value adding it to the Stream useful when you make use of Rx for custom Types to refresh your UI.
inherited
close() → void
Close the Rx Variable
inherited
containsId(Object id) bool
Returns true if a listener group with the given id exists.
inherited
containsListener(GetStateUpdate listener) bool
Returns true if listener is currently registered.
inherited
dispose() → void
Disposes all listeners and marks the notifier as disposed.
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
listen(void onData(bool?)?, {Function? onError, void onDone()?, bool? cancelOnError}) StreamSubscription<bool?>
Calls callback with current value, when the value changes.
inherited
listenAndPump(void onData(bool? event), {Function? onError, void onDone()?, bool? cancelOnError}) StreamSubscription<bool?>
Returns a StreamSubscription similar to listen, but with the added benefit that it primes the stream with the current value, rather than waiting for the next value. This should not be called in onInit or anywhere else during the build process.
inherited
map<R>(R mapper(bool? data)) Stream<R>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyGroupChildrens(Object id) → void
Reports a read to the Notifier system for the group identified by id.
inherited
refresh() → void
Notifies all registered listeners to trigger a rebuild.
inherited
refreshGroup(Object id) → void
Notifies all listeners in the group identified by id.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
Removes a listener from the group identified by id.
inherited
reportAdd(VoidCallback disposer) → void
Reports a disposer callback to the Notifier system for cleanup.
inherited
reportRead() → void
Reports a read access to the Notifier system so reactive widgets can track dependencies.
inherited
toggle() → void

Available on Rx<bool>, provided by the RxBoolExt extension

Toggles the bool value between false and true. A shortcut for flag.value = !flag.value;
toggle() → void

Available on Rx<bool?>, provided by the RxnBoolExt extension

Toggles the bool value between false and true. A shortcut for flag.value = !flag.value;
toJson() → dynamic
Returns the json representation of value.
inherited
toString() String
A string representation of this object.
override
trigger(bool? v) → void
Following certain practices on Rx data, we might want to react to certain listeners when a value has been provided, even if the value is the same. At the moment, we ignore part of the process if we .call(value) with the same value since it holds the value and there's no real need triggering the entire process for the same value inside, but there are other situations where we might be interested in triggering this.
inherited
update(bool? fn(bool? val)) → void
Uses a callback to update value internally, similar to refresh, but provides the current value as the argument. Makes sense for custom Rx types (like Models).
inherited

Operators

operator &(bool other) bool

Available on Rx<bool>, provided by the RxBoolExt extension

Logical AND with other.
operator &(bool other) bool?

Available on Rx<bool?>, provided by the RxnBoolExt extension

Nullable logical AND with other.
operator ==(Object o) bool
This equality override works for _RxImpl instances and the internal values.
inherited
operator ^(bool other) bool

Available on Rx<bool>, provided by the RxBoolExt extension

Logical XOR with other.
operator ^(bool other) bool?

Available on Rx<bool?>, provided by the RxnBoolExt extension

Nullable logical XOR with other.
operator |(bool other) bool

Available on Rx<bool>, provided by the RxBoolExt extension

Logical OR with other.
operator |(bool other) bool?

Available on Rx<bool?>, provided by the RxnBoolExt extension

Nullable logical OR with other.